package com.chinaitop.depot.business.controller;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.business.model.BusinessNoticeReceive;
import com.chinaitop.depot.business.service.ReceiveNoticeService;
import com.chinaitop.depot.business.service.SystemOutsideDataService;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 接收通知单
 * @author My   Sunshine
 *
 */
@RestController
@RequestMapping(value="/depot/business/receiveNotice")
@Api(description = "接收通知单")
public class ReceiveNoticeController {

	public static final Logger logger = LoggerFactory.getLogger(ReceiveNoticeController.class);
	
	@Resource
	private ReceiveNoticeService receiveNoticeService;

	@Resource
	private SystemOutsideDataService systemOutsideDataService;


	/**
	 * 接收通知单列表
	 */
	@RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="通知单接收列表", notes = "查询数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "当前登录的用户编号", paramType = "query")
    })
    public PageInfo<BusinessNoticeReceive> getList(Integer pageNum, Integer pageSize , BusinessNoticeReceive businessNoticeReceive,String cktzd,String lyflag) throws Exception {

        List<BusinessNoticeReceive> list = receiveNoticeService.queryByExample(pageNum, pageSize, businessNoticeReceive,cktzd,lyflag);
        PageInfo<BusinessNoticeReceive> pageInfo = new PageInfo<BusinessNoticeReceive>(list);
        return pageInfo;
    }
   
	
	
	
	/**
	 * 根据id查询
	 */
	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.GET)
    @ApiOperation(value="根据接收的通知单id查找信息", notes = "根据id查找")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "接收的通知单id", paramType = "query")
    })
    public BusinessNoticeReceive edit(Integer id) {
		BusinessNoticeReceive businessNoticeReceive = new BusinessNoticeReceive();
        if (id != null) {
        	businessNoticeReceive = receiveNoticeService.findById(id);
        }else{
        	businessNoticeReceive=new BusinessNoticeReceive();
        }

        return businessNoticeReceive;
    }
	
	
	
	/**
	 * 修改
	 */
	@RequestMapping(value="/update", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.POST)
    @ApiOperation(value="修改内容", notes = "修改内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "BusinessNoticeReceive", value = "接收到的通知单对象", paramType = "form")
    })
    public Map<String, Object> update(BusinessNoticeReceive businessNoticeReceive) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		if(businessNoticeReceive.getInApplication()!=null){
			receiveNoticeService.update(businessNoticeReceive);
			modelMap.put("status", "success");
		}else{
			modelMap.put("status", "error");
		}
        return modelMap;
    }
	
	/**
	 * 新增
	 */
	@RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存数据", notes = "保存")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "notice", value = "JSON对象数据", paramType = "form")
	})
    public Map<String, Object> save(String notice){

		logger.info("市平台传推送过来的轮换通知单如下：");
		logger.info(notice);
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
			modelMap = receiveNoticeService.receiveNotice(notice);
			systemOutsideDataService.addlogger("tzdjs", notice, modelMap.toString());
		} catch (Exception e) {
			modelMap.put("status", "error");
			modelMap.put("msg", "接口异常，请联系管理员！");
			logger.error(e.getMessage(), e);
			systemOutsideDataService.addlogger("tzdjs", notice, modelMap.toString());
		}
		return modelMap;
    }

	@RequestMapping(value="/updateHtbh", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="修改当前数据的合同编号", notes = "")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "notice", value = "JSON对象数据", paramType = "form")
	})
	public Map<String, Object> update(String notice) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
			modelMap = receiveNoticeService.updateReceiveNotice(notice);
			//给市平台推送合同被引用的消息
			receiveNoticeService.pushHtStatus(notice);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
			modelMap.put("status", 500);
			modelMap.put("msg", "操作失败");
		}
		return modelMap;
	}
	
	
	/**
	 * 未进行审核完成的【性质转变单】，该仓再下一次申请入库验收的时候，
	 * 会提示，需要将上一次的粮食性质转变单审核完成，才能进行提交
	 */
	@RequestMapping(value="/getNoticeNoAuditList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="入库验收申请时查询上一次性质转变单是否审批完成", notes = "入库验收申请时查询上一次性质转变单是否审批完成")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "xybh", value = "协议编号", paramType = "query"),
            @ApiImplicitParam(name = "sptDataId", value = "和市平台对接的货位编码", paramType = "query"),
            @ApiImplicitParam(name = "flag", value = "是油罐还是仓房", paramType = "query")
    })
    public int getNoticeNoAuditList(String xybh,String sptDataId,Integer flag) throws Exception {
        return receiveNoticeService.queryIsOrAudit(xybh,sptDataId,flag);
    }
	
	
	@RequestMapping(value="/saveDataRk", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="增加性质转变单数据(入库)", notes = "增加性质转变单数据(入库)")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query"),
        @ApiImplicitParam(name = "storehouseId", value = "仓房", paramType = "query"),
        @ApiImplicitParam(name = "warehouseId", value = "货位", paramType = "query"),
        @ApiImplicitParam(name = "rksl", value = "入库数量", paramType = "query"),
        @ApiImplicitParam(name = "grainVarietyName", value = "品种名称", paramType = "query")
    })
    public void saveDataRk(String orgId,Integer storehouseId,Integer warehouseId,String grainVarietyName,
    		BigDecimal rksl,String lsxzzbdh) {
		
		 logger.info("接收到的参数是："+orgId+"--"+storehouseId+"**"+warehouseId+"**"+grainVarietyName+"**"+rksl+"//"+lsxzzbdh);
		receiveNoticeService.saveDataRk( orgId, storehouseId, warehouseId, grainVarietyName,
	    		 rksl, lsxzzbdh,null);
    	
    }
	
	
	@RequestMapping(value="/saveDataRkByRest", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="增加性质转变单数据(入库)", notes = "增加性质转变单数据(入库)")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query"),
        @ApiImplicitParam(name = "storehouseId", value = "仓房", paramType = "query"),
        @ApiImplicitParam(name = "warehouseId", value = "货位", paramType = "query"),
        @ApiImplicitParam(name = "rksl", value = "入库数量", paramType = "query"),
        @ApiImplicitParam(name = "grainVarietyName", value = "品种名称", paramType = "query")
    })
	public void saveDataRkByRest(@RequestBody MultiValueMap<String,String> map) {
		
		logger.info("入库验收接收到的性质转变单:"+map);
		List<String> orgIdList = map.get("orgId");
		String orgId = (String) orgIdList.get(0);
		
		List<String> storehouseIdList = map.get("storehouseId");
		Integer storehouseId = Integer.valueOf(storehouseIdList.get(0));
		
		List<String> warehouseIdList = map.get("warehouseId");
		Integer warehouseId = Integer.valueOf(warehouseIdList.get(0));

		
		List<String> grainVarietyNameList = map.get("grainVarietyName");
		String grainVarietyName = (String) grainVarietyNameList.get(0);
		
		List<String> rkslList = map.get("rksl");
		BigDecimal rksl = new BigDecimal(rkslList.get(0));
	
		List<String> lsxzzbdhList =  map.get("lsxzzbdh");
		String lsxzzbdh = lsxzzbdhList.get(0);
		
		List<String> xyhList =  map.get("xyh");
		String xyh = xyhList.get(0);
		
		logger.info("接收到的参数是：orgId:"+orgId+"--"+"storehouseId:"+storehouseId+"**"+warehouseId+"**"+grainVarietyName+"**"+rksl+"//"+lsxzzbdh);
		receiveNoticeService.saveDataRk( orgId, storehouseId, warehouseId, grainVarietyName,
	    		 rksl, lsxzzbdh, xyh);
    }
	
	
    
}
